local table = require('table')
local top_srcdir = require('os').getenv('top_srcdir') or '.'

local db = table.concat( { top_srcdir, 'tests', 'data', 'test.rdb'}, '/' )

local rdb = require( 'rdb' )


describe( "match", function ()

  describe( "table", function ()

    local nmatch = rdb.select{ file = db, match = { x = 3 } }

    it( "number of matches", function ()
      assert.is.equal( 1, #nmatch )
    end)

    it( "data", function ()
      assert.are.same( { { x = 3, y = 2 } }, nmatch )
    end)

  end)

  describe( "func", function ()

   local nmatch = rdb.select{ file = db,
                            match = function(rec)
                                       return rec.y < 9
                                    end,
                           }


    it( "number of matches", function ()
        assert.is.equal( 2, #nmatch )
    end)


    it( "data", function ()
      assert.are.same( { { x = 3, y = 2 }, { x = 5, y = 4 } }, nmatch )
    end)

  end)

  describe( "iterator", function ()

    local data = rdb.slurp( db )

    local iter = rdb.select{ file = db,
                           match = function(rec)
                                      return rec.y < 9
                                   end,
                           mode = 'iterator'
                          }

    local nrow = 1

    for rec, idx in iter do

       local lnrow = nrow

      describe( "row index", function ()
        assert.is.equal( lnrow, idx )
      end)

      describe( "row data", function ()
        assert.are.same( data[idx], rec )
      end)

      nrow = nrow + 1

    end

    it( "number of matches", function ()
        assert.is.equal( 3, nrow )
    end)

  end)

  describe( "table", function ()

   local nmatch = rdb.select{ file = db,
                              match = { y = { 2, 9 } }
                           }

    it( "number of matches", function ()
        assert.is.equal( 2, #nmatch )
    end)

    it( "data", function ()
      assert.are.same( { { x = 3, y = 2 }, { x = 22, y = 9 } }, nmatch )
    end)

  end)


end)
